## ❓ _Why This Change_
-

## 🆕 _What Changed_
-
-

## 🧪 _Test Results_
```


```

## :shipit: _Ready Checks_
- [ ] These changes have been carefully tested across multiple macOS versions
- [ ] Where logical, code updates include inline comments/docstrings
